@@ -6,22 +6,13 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
     let auth = AuthDetails::from_query_string(&auth_qs)?;
     let client = Client::with_auth(auth);
 
-    let req = posts()
-        .limit(5)
-        .rating(Rating::Safe)
-        .tags(&["hatsune_miku", "solo"])
-        .tags_raw("aqua_hair");
+    let tags = tags().limit(5).after_id(69420)
+        .ascending(false)
+        .order_by(Ordering::Date)
+        .send(&client).await?;
 
-    let posts = req.send(&client).await?;
-
-    for post in posts {
-        println!(
-            "Post {id} created at {created_at} by {owner} [{image_url}]",
-            id = post.id(),
-            created_at = post.created_at(),
-            owner = post.owner(),
-            image_url = post.image_url(),
-        );
+    for tag in tags {
+        dbg!(tag);
     }
 
     /*
